EXPORTS
	??0RGavdp@@QAE@XZ @ 1 NONAME ; RGavdp::RGavdp(void)
	?AbortStream@RGavdp@@QAEXVTSEID@@@Z @ 2 NONAME ; void RGavdp::AbortStream(class TSEID)
	?AddSEPCapability@RGavdp@@QAEHABVTAvdtpServiceCapability@@@Z @ 3 NONAME ; int RGavdp::AddSEPCapability(class TAvdtpServiceCapability const &)
	?BeginConfiguringLocalSEP@RGavdp@@QAEHVTSEID@@@Z @ 4 NONAME ; int RGavdp::BeginConfiguringLocalSEP(class TSEID)
	?BeginConfiguringRemoteSEP@RGavdp@@QAEHVTSEID@@0@Z @ 5 NONAME ; int RGavdp::BeginConfiguringRemoteSEP(class TSEID, class TSEID)
	?Cancel@RGavdp@@QAEXXZ @ 6 NONAME ; void RGavdp::Cancel(void)
	?Close@RGavdp@@QAEXXZ @ 7 NONAME ; void RGavdp::Close(void)
	?CommitSEPConfiguration@RGavdp@@QAEXXZ @ 8 NONAME ; void RGavdp::CommitSEPConfiguration(void)
	?Connect@RGavdp@@QAEXABVTBTDevAddr@@@Z @ 9 NONAME ; void RGavdp::Connect(class TBTDevAddr const &)
	?CreateBearerSockets@RGavdp@@QAEHVTSEID@@HH@Z @ 10 NONAME ; int RGavdp::CreateBearerSockets(class TSEID, int, int)
	?DiscoverRemoteSEPs@RGavdp@@QAEXXZ @ 11 NONAME ; void RGavdp::DiscoverRemoteSEPs(void)
	?GetRemoteSEPCapabilities@RGavdp@@QAEXVTSEID@@ABVTAvdtpServiceCategories@@@Z @ 12 NONAME ; void RGavdp::GetRemoteSEPCapabilities(class TSEID, class TAvdtpServiceCategories const &)
	?Listen@RGavdp@@QAEHXZ @ 13 NONAME ; int RGavdp::Listen(void)
	?MaxSecurityControlLength@RGavdp@@QAEHXZ @ 14 NONAME ; int RGavdp::MaxSecurityControlLength(void)
	?Open@RGavdp@@QAEHAAVMGavdpUser@@AAVRSocketServ@@@Z @ 15 NONAME ; int RGavdp::Open(class MGavdpUser &, class RSocketServ &)
	?RegisterSEP@RGavdp@@QAEHAAVTAvdtpSEPInfo@@@Z @ 16 NONAME ; int RGavdp::RegisterSEP(class TAvdtpSEPInfo &)
	?SendSecurityControl@RGavdp@@QAEXVTSEID@@ABVTDesC8@@@Z @ 17 NONAME ; void RGavdp::SendSecurityControl(class TSEID, class TDesC8 const &)
	?StartStream@RGavdp@@QAEXVTSEID@@@Z @ 18 NONAME ; void RGavdp::StartStream(class TSEID)
	?SuspendStream@RGavdp@@QAEXVTSEID@@@Z @ 19 NONAME ; void RGavdp::SuspendStream(class TSEID)
	?CreateBearerSockets@RGavdp@@QAEHVTSEID@@@Z @ 20 NONAME ; int RGavdp::CreateBearerSockets(class TSEID)
	?Shutdown@RGavdp@@QAEHXZ @ 21 NONAME ; int RGavdp::Shutdown(void)

